aboutsummaryrefslogtreecommitdiff
path: root/src/RWADBusAdaptor.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/RWADBusAdaptor.h')
-rw-r--r--src/RWADBusAdaptor.h66
1 files changed, 59 insertions, 7 deletions
diff --git a/src/RWADBusAdaptor.h b/src/RWADBusAdaptor.h
index 4fbad44..741687f 100644
--- a/src/RWADBusAdaptor.h
+++ b/src/RWADBusAdaptor.h
@@ -1,6 +1,7 @@
/*
* This file was generated by qdbusxml2cpp version 0.8
* Command line was: qdbusxml2cpp -p RWADBusAdaptor.h: rwa.xml
*
* qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
*
@@ -21,9 +22,9 @@
#include <QtDBus/QtDBus>
/*
* Proxy class for interface org.ArcticaProject.RWA
*/
-class OrgArcticaProjectRWAInterface: public QDBusAbstractInterface
+class OrgArcticaProjectRWASupportSessionServiceInterface: public QDBusAbstractInterface
{
Q_OBJECT
public:
@@ -31,11 +32,24 @@ public:
{ return "org.ArcticaProject.RWASupportSessionService"; }
public:
- OrgArcticaProjectRWAInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);
+ OrgArcticaProjectRWASupportSessionServiceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);
- ~OrgArcticaProjectRWAInterface();
+ ~OrgArcticaProjectRWASupportSessionServiceInterface();
public Q_SLOTS: // METHODS
+ inline QDBusPendingReply<QString> add_web_app_host(const QString &host)
+ {
+ QList<QVariant> argumentList;
+ argumentList << QVariant::fromValue(host);
+ return asyncCallWithArgumentList(QStringLiteral("add_web_app_host"), argumentList);
+ }
+
+ inline QDBusPendingReply<QString> get_web_app_hosts()
+ {
+ QList<QVariant> argumentList;
+ return asyncCallWithArgumentList(QStringLiteral("get_web_app_hosts"), argumentList);
+ }
+
inline QDBusPendingReply<QString> refresh_status(int pid)
{
QList<QVariant> argumentList;
@@ -43,9 +57,17 @@ public Q_SLOTS: // METHODS
return asyncCallWithArgumentList(QStringLiteral("refresh_status"), argumentList);
}
- inline QDBusPendingReply<QString> start()
+ inline QDBusPendingReply<QString> remove_web_app_host(int host_idx)
{
QList<QVariant> argumentList;
+ argumentList << QVariant::fromValue(host_idx);
+ return asyncCallWithArgumentList(QStringLiteral("remove_web_app_host"), argumentList);
+ }
+
+ inline QDBusPendingReply<QString> start(int host_idx)
+ {
+ QList<QVariant> argumentList;
+ argumentList << QVariant::fromValue(host_idx);
return asyncCallWithArgumentList(QStringLiteral("start"), argumentList);
}
@@ -66,9 +88,39 @@ public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
};
+/*
+ * Proxy class for interface org.freedesktop.DBus.Introspectable
+ */
+class OrgFreedesktopDBusIntrospectableInterface: public QDBusAbstractInterface
+{
+ Q_OBJECT
+public:
+ static inline const char *staticInterfaceName()
+ { return "org.freedesktop.DBus.Introspectable"; }
+
+public:
+ OrgFreedesktopDBusIntrospectableInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);
+
+ ~OrgFreedesktopDBusIntrospectableInterface();
+
+public Q_SLOTS: // METHODS
+ inline QDBusPendingReply<QString> Introspect()
+ {
+ QList<QVariant> argumentList;
+ return asyncCallWithArgumentList(QStringLiteral("Introspect"), argumentList);
+ }
+
+Q_SIGNALS: // SIGNALS
+};
+
namespace org {
namespace ArcticaProject {
- typedef ::OrgArcticaProjectRWAInterface RWA;
+ typedef ::OrgArcticaProjectRWASupportSessionServiceInterface RWASupportSessionService;
+ }
+ namespace freedesktop {
+ namespace DBus {
+ typedef ::OrgFreedesktopDBusIntrospectableInterface Introspectable;
+ }
}
}
#endif
@@ -1,6 +1,7 @@
/*
* This file was generated by qdbusxml2cpp version 0.8
- * Command line was: qdbusxml2cpp -p RWADBusAdaptor.h: rwa.xml
+ * Command line was: qdbusxml2cpp -p src/RWADBusAdaptor.h: rwa.xml
+ * rwa.xml is the xml output of the Introspect D-Bus method
*
* qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
@@ -21,9 +22,9 @@
#include <QtDBus/QtDBus>
/*
- * Proxy class for interface org.ArcticaProject.RWA
+ * Proxy class for interface org.ArcticaProject.RWASupportSessionService
*/